@@ -9,6 +9,10 @@ from kubernetes.client import V1Capabilities
 from kubernetes.client import V1EnvVar
 from kubernetes.client import V1EnvVarSource
 from kubernetes.client import V1HostPathVolumeSource
+from kubernetes.client import V1NodeAffinity
+from kubernetes.client import V1NodeSelector
+from kubernetes.client import V1NodeSelectorRequirement
+from kubernetes.client import V1NodeSelectorTerm
 from kubernetes.client import V1SecretKeySelector
 from kubernetes.client import V1SecurityContext
 from kubernetes.client import V1Volume
@@ -16,8 +20,10 @@ from kubernetes.client import V1VolumeMount
 from pyrsistent.typing import PMap
 from pyrsistent.typing import PVector
 
+from task_processing.plugins.kubernetes.types import NodeAffinityOperator
 if TYPE_CHECKING:
     from task_processing.plugins.kubernetes.types import DockerVolume
+    from task_processing.plugins.kubernetes.types import NodeAffinity
     from task_processing.plugins.kubernetes.types import SecretEnvSource
 
 logger = logging.getLogger(__name__)
@@ -62,7 +68,7 @@ def get_kubernetes_env_vars(
     secret_env_vars = [
         V1EnvVar(name=key, value_from=V1EnvVarSource(
             secret_key_ref=V1SecretKeySelector(
-                name=value["secret"],
+                name=value["secret_name"],
                 key=value["key"],
                 optional=False,
             ),
@@ -144,3 +150,35 @@ def get_pod_volumes(volumes: PVector['DockerVolume']) -> List[V1Volume]:
         )
         for name, volume in unique_volumes.items()
     ]
+
+
+def get_node_affinity(affinities: PVector["NodeAffinity"]) -> Optional[V1NodeAffinity]:
+    # convert NodeAffinity into V1NodeSelectorRequirement
+    match_expressions = []
+    for aff in affinities:
+        op = aff["operator"]
+        val = aff["value"]
+
+        # operator and value are assumed to be validated
+        if op in {NodeAffinityOperator.IN, NodeAffinityOperator.NOT_IN}:
+            val = [str(v) for v in val]
+        elif op in {NodeAffinityOperator.GT, NodeAffinityOperator.LT}:
+            val = [str(val)]
+        elif op in {NodeAffinityOperator.EXISTS, NodeAffinityOperator.DOES_NOT_EXIST}:
+            val = []
+        else:
+            continue
+        match_expressions.append(
+            V1NodeSelectorRequirement(key=str(aff["key"]), operator=op, values=val)
+        )
+
+    # package into V1NodeAffinity
+    if not match_expressions:
+        return None
+    return V1NodeAffinity(
+        # this means that the selectors are only used during scheduling.
+        # changing it while the pod is running will not cause an eviction.
+        required_during_scheduling_ignored_during_execution=V1NodeSelector(
+            node_selector_terms=[V1NodeSelectorTerm(match_expressions=match_expressions)],
+        ),
+    )
